@@ -4,7 +4,7 @@ __author__ = 'Altertech, https://www.altertech.com/'
 __copyright__ = 'Copyright (C) 2020 Altertech'
 __license__ = 'Apache License 2.0'
 
-__version__ = '0.1.7'
+__version__ = '0.1.8'
 
 import sys
 import argparse
@@ -129,7 +129,7 @@ def do(loop=False):
     t = perf_counter()
 
     next_iter = t + interval
-    next_beacon = t + +beacon_interval
+    next_beacon = t + beacon_interval
 
     def pull_and_process():
         nonlocal next_iter, next_beacon
